@@ -2,22 +2,24 @@
 function(){
 
   if(!exists('slider.env')) slider.env<<-new.env()
-  #library(tcltk)
+  if(!require(tcltk)) {
+      stop('This function needs the tcltk package')
+  }
 
-  shape <- 1; assign('shape',tclVar(shape),env=slider.env)
-  rate  <- 1; assign('rate',tclVar(rate),env=slider.env)
-  scale <- 1; assign('scale',tclVar(scale),env=slider.env)
-  mean  <- 1; assign('mean', tclVar(mean), env=slider.env)
-  sd    <- 1; assign('sd',tclVar(sd), env=slider.env)
+  shape <- 1; assign('shape',tclVar(shape),envir=slider.env)
+  rate  <- 1; assign('rate',tclVar(rate),envir=slider.env)
+  scale <- 1; assign('scale',tclVar(scale),envir=slider.env)
+  mean  <- 1; assign('mean', tclVar(mean), envir=slider.env)
+  sd    <- 1; assign('sd',tclVar(sd), envir=slider.env)
 
-  se <- 0; assign('se', tclVar(se), env=slider.env)
-  sc2 <- 0; assign('sc2', tclVar(sc2), env=slider.env)
-  sg <- 1; assign('sg', tclVar(sg), env=slider.env)
+  se <- 0; assign('se', tclVar(se), envir=slider.env)
+  sc2 <- 0; assign('sc2', tclVar(sc2), envir=slider.env)
+  sg <- 1; assign('sg', tclVar(sg), envir=slider.env)
 
-  xmin <- 0; assign('xmin',tclVar(xmin),env=slider.env)
-  xmax <- 5; assign('xmax',tclVar(xmax),env=slider.env)
-  ymin <- 0; assign('ymin',tclVar(ymin),env=slider.env)
-  ymax <- 1; assign('ymax',tclVar(ymax),env=slider.env)
+  xmin <- 0; assign('xmin',tclVar(xmin),envir=slider.env)
+  xmax <- 5; assign('xmax',tclVar(xmax),envir=slider.env)
+  ymin <- 0; assign('ymin',tclVar(ymin),envir=slider.env)
+  ymax <- 1; assign('ymax',tclVar(ymax),envir=slider.env)
 
   old.shape <- shape
   old.rate  <- rate
@@ -28,11 +30,11 @@ function(){
 
   gamma.refresh <- function(...){
 
-    shape <- as.numeric(evalq(tclvalue(shape), env=slider.env))
-    rate  <- as.numeric(evalq(tclvalue(rate), env=slider.env))
-    scale <- as.numeric(evalq(tclvalue(scale), env=slider.env))
-    mean  <- as.numeric(evalq(tclvalue(mean), env=slider.env))
-    sd    <- as.numeric(evalq(tclvalue(sd), env=slider.env))
+    shape <- as.numeric(evalq(tclvalue(shape), envir=slider.env))
+    rate  <- as.numeric(evalq(tclvalue(rate), envir=slider.env))
+    scale <- as.numeric(evalq(tclvalue(scale), envir=slider.env))
+    mean  <- as.numeric(evalq(tclvalue(mean), envir=slider.env))
+    sd    <- as.numeric(evalq(tclvalue(sd), envir=slider.env))
 
     if ( shape != old.shape ) {
 
@@ -40,9 +42,9 @@ function(){
       sd <- round( sqrt(shape)*scale, 6 );
 
       try(eval(parse(text=paste("tclvalue(mean)<-",
-                       mean,sep="")),env=slider.env));
+                       mean,sep="")),envir=slider.env));
       try(eval(parse(text=paste("tclvalue(sd)<-",
-                       sd,sep="")),env=slider.env));
+                       sd,sep="")),envir=slider.env));
       old.shape <<- shape; old.mean <<- mean; old.sd <<- sd
 
     }
@@ -54,11 +56,11 @@ function(){
       sd <- round( sqrt(shape)*scale, 6 );
 
       try(eval(parse(text=paste("tclvalue(scale)<-",
-                       scale,sep="")),env=slider.env));
+                       scale,sep="")),envir=slider.env));
       try(eval(parse(text=paste("tclvalue(mean)<-",
-                       mean,sep="")),env=slider.env));
+                       mean,sep="")),envir=slider.env));
       try(eval(parse(text=paste("tclvalue(sd)<-",
-                       sd,sep="")),env=slider.env));
+                       sd,sep="")),envir=slider.env));
       old.rate <<- rate; old.scale <<- scale;
       old.mean <<- mean; old.sd <<- sd
 
@@ -71,11 +73,11 @@ function(){
       sd <- round( sqrt(shape)*scale, 6 );
 
       try(eval(parse(text=paste("tclvalue(rate)<-",
-                       rate,sep="")),env=slider.env));
+                       rate,sep="")),envir=slider.env));
       try(eval(parse(text=paste("tclvalue(mean)<-",
-                       mean,sep="")),env=slider.env));
+                       mean,sep="")),envir=slider.env));
       try(eval(parse(text=paste("tclvalue(sd)<-",
-                       sd,sep="")),env=slider.env));
+                       sd,sep="")),envir=slider.env));
       old.rate <<- rate; old.scale <<- scale;
       old.mean <<- mean; old.sd <<- sd
 
@@ -88,11 +90,11 @@ function(){
       rate <- round(1/scale, 6)
 
       try(eval(parse(text=paste("tclvalue(rate)<-",
-                       rate,sep="")),env=slider.env));
+                       rate,sep="")),envir=slider.env));
       try(eval(parse(text=paste("tclvalue(shape)<-",
-                       shape,sep="")),env=slider.env));
+                       shape,sep="")),envir=slider.env));
       try(eval(parse(text=paste("tclvalue(scale)<-",
-                       scale,sep="")),env=slider.env));
+                       scale,sep="")),envir=slider.env));
       old.shape <<- shape; old.rate <<- rate; old.scale <<- scale;
       old.mean <<- mean; old.sd <<- sd
 
@@ -106,25 +108,25 @@ function(){
       rate <- round(1/scale, 6)
 
       try(eval(parse(text=paste("tclvalue(rate)<-",
-                       rate,sep="")),env=slider.env));
+                       rate,sep="")),envir=slider.env));
       try(eval(parse(text=paste("tclvalue(shape)<-",
-                       shape,sep="")),env=slider.env));
+                       shape,sep="")),envir=slider.env));
       try(eval(parse(text=paste("tclvalue(scale)<-",
-                       scale,sep="")),env=slider.env));
+                       scale,sep="")),envir=slider.env));
       old.shape <<- shape; old.rate <<- rate; old.scale <<- scale;
       old.mean <<- mean; old.sd <<- sd
 
     }
 
 
-    se <- as.numeric(evalq(tclvalue(se), env=slider.env))
-    sc2 <- as.numeric(evalq(tclvalue(sc2), env=slider.env))
-    sg <- as.numeric(evalq(tclvalue(sg), env=slider.env))
+    se <- as.numeric(evalq(tclvalue(se), envir=slider.env))
+    sc2 <- as.numeric(evalq(tclvalue(sc2), envir=slider.env))
+    sg <- as.numeric(evalq(tclvalue(sg), envir=slider.env))
 
-    xmin <- as.numeric(evalq(tclvalue(xmin), env=slider.env))
-    xmax <- as.numeric(evalq(tclvalue(xmax), env=slider.env))
-    ymin <- as.numeric(evalq(tclvalue(ymin), env=slider.env))
-    ymax <- as.numeric(evalq(tclvalue(ymax), env=slider.env))
+    xmin <- as.numeric(evalq(tclvalue(xmin), envir=slider.env))
+    xmax <- as.numeric(evalq(tclvalue(xmax), envir=slider.env))
+    ymin <- as.numeric(evalq(tclvalue(ymin), envir=slider.env))
+    ymax <- as.numeric(evalq(tclvalue(ymax), envir=slider.env))
 
     xx <- seq(xmin,xmax, length=500)
 
@@ -168,8 +170,8 @@ function(){
                        orient='horiz',
                        resolution=0.1, showvalue=T),
          side='left')
-  assign('sc',sc,env=slider.env)
-  evalq(tkconfigure(sc, variable=shape),env=slider.env)
+  assign('sc',sc,envir=slider.env)
+  evalq(tkconfigure(sc, variable=shape),envir=slider.env)
 
   # rate
   tkpack(fr <- tkframe(m),side='top')
@@ -178,8 +180,8 @@ function(){
                        orient='horiz',
                        resolution=0.1, showvalue=T),
          side='left')
-  assign('sc',sc,env=slider.env)
-  evalq(tkconfigure(sc, variable=rate),env=slider.env)
+  assign('sc',sc,envir=slider.env)
+  evalq(tkconfigure(sc, variable=rate),envir=slider.env)
 
   # scale
   tkpack(fr <- tkframe(m),side='top')
@@ -188,8 +190,8 @@ function(){
                        orient='horiz',
                        resolution=0.1, showvalue=T),
          side='left')
-  assign('sc',sc,env=slider.env)
-  evalq(tkconfigure(sc, variable=scale),env=slider.env)
+  assign('sc',sc,envir=slider.env)
+  evalq(tkconfigure(sc, variable=scale),envir=slider.env)
 
   # mean
   tkpack(fr <- tkframe(m),side='top')
@@ -198,8 +200,8 @@ function(){
                        orient='horiz',
                        resolution=0.1, showvalue=T),
          side='left')
-  assign('sc',sc,env=slider.env)
-  evalq(tkconfigure(sc, variable=mean),env=slider.env)
+  assign('sc',sc,envir=slider.env)
+  evalq(tkconfigure(sc, variable=mean),envir=slider.env)
 
   # sd
   tkpack(fr <- tkframe(m),side='top')
@@ -208,8 +210,8 @@ function(){
                        orient='horiz',
                        resolution=0.1, showvalue=T),
          side='left')
-  assign('sc',sc,env=slider.env)
-  evalq(tkconfigure(sc, variable=sd),env=slider.env)
+  assign('sc',sc,envir=slider.env)
+  evalq(tkconfigure(sc, variable=sd),envir=slider.env)
 
 
   # show exponential
@@ -218,8 +220,8 @@ function(){
          side='left')
   tkpack(tklabel(fr, text='Show Exponential Distribution', width='25'),
          side='left')
-  assign('sc',sc,env=slider.env)
-  evalq(tkconfigure(sc, variable=se),env=slider.env)
+  assign('sc',sc,envir=slider.env)
+  evalq(tkconfigure(sc, variable=se),envir=slider.env)
 
   # show chisquared
   tkpack(fr <- tkframe(m),side='top')
@@ -227,8 +229,8 @@ function(){
          side='left')
   tkpack(tklabel(fr, text='Show Chi-squared Distribution', width='25'),
          side='left')
-  assign('sc',sc,env=slider.env)
-  evalq(tkconfigure(sc, variable=sc2),env=slider.env)
+  assign('sc',sc,envir=slider.env)
+  evalq(tkconfigure(sc, variable=sc2),envir=slider.env)
 
   # show gamma
   tkpack(fr <- tkframe(m),side='top')
@@ -236,35 +238,35 @@ function(){
          side='left')
   tkpack(tklabel(fr, text='Show Gamma Distribution', width='25'),
          side='left')
-  assign('sc',sc,env=slider.env)
-  evalq(tkconfigure(sc, variable=sg),env=slider.env)
+  assign('sc',sc,envir=slider.env)
+  evalq(tkconfigure(sc, variable=sg),envir=slider.env)
 
 
   # xmin
   tkpack(fr <- tkframe(m),side='top')
   tkpack(tklabel(fr, text='Xmin:', width=6), side='left')
   tkpack(e <- tkentry(fr,width=8), side='left')
-  assign('e',e,env=slider.env)
-  evalq(tkconfigure(e, textvariable=xmin), env=slider.env)
+  assign('e',e,envir=slider.env)
+  evalq(tkconfigure(e, textvariable=xmin), envir=slider.env)
 
   # xmax
   tkpack(tklabel(fr, text='Xmax:', width=6), side='left')
   tkpack(e <- tkentry(fr,width=8), side='left')
-  assign('e',e,env=slider.env)
-  evalq(tkconfigure(e, textvariable=xmax), env=slider.env)
+  assign('e',e,envir=slider.env)
+  evalq(tkconfigure(e, textvariable=xmax), envir=slider.env)
 
   # ymin
   tkpack(fr <- tkframe(m),side='top')
   tkpack(tklabel(fr, text='Ymin:', width=6), side='left')
   tkpack(e <- tkentry(fr,width=8), side='left')
-  assign('e',e,env=slider.env)
-  evalq(tkconfigure(e, textvariable=ymin), env=slider.env)
+  assign('e',e,envir=slider.env)
+  evalq(tkconfigure(e, textvariable=ymin), envir=slider.env)
 
   # ymax
   tkpack(tklabel(fr, text='Ymax:', width=6), side='left')
   tkpack(e <- tkentry(fr,width=8), side='left')
-  assign('e',e,env=slider.env)
-  evalq(tkconfigure(e, textvariable=ymax), env=slider.env)
+  assign('e',e,envir=slider.env)
+  evalq(tkconfigure(e, textvariable=ymax), envir=slider.env)
 
 
   tkpack(tkbutton(m, text="Refresh", command=gamma.refresh),side='left')
